@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from contextlib import contextmanager
 from typing import List, Tuple
 
 
@@ -28,6 +29,12 @@ class ListNode(Node, ABC):
 class Document:
     header_level = 1
     indent_level = 0
+
+    indent_spaces = 2
+    """Amount of spaces used for indentation. For item blocks in lists,
+    this must be larger than the list marker:
+    https://github.github.com/gfm/#example-232"""
+
     nodes: List[Tuple[int, Node]] = []
 
     @classmethod
@@ -45,3 +52,13 @@ class Document:
                 out += str(node)
 
         return out
+
+
+@contextmanager
+def set_indent_spaces(spaces: int):
+    old = Document.indent_spaces
+    Document.indent_spaces = spaces
+    try:
+        yield
+    finally:
+        Document.indent_spaces = old
