@@ -43,8 +43,10 @@ class UnorderedList(ListNode):
                 Document.indent_level -= 1
 
             else:
-                out += f"{'  ' * Document.indent_level}- {item}\n"
+                out += f"{' ' * Document.indent_spaces * Document.indent_level}- {item}\n"
 
+        if Document.indent_level > 0:
+            return out
         return out + "\n"
 
 
@@ -58,14 +60,17 @@ class OrderedList(ListNode):
         for item in self.items:
             if isinstance(item, ListNode):
                 Document.indent_level += 1
-                out += str(item)
+                with set_indent_spaces(len(str(index)) + 2):
+                    out += str(item)
                 Document.indent_level -= 1
 
             else:
-                out += f"{'  ' * Document.indent_level}{index}. {item}\n"
+                out += f"{' ' * Document.indent_spaces * Document.indent_level}{index}. {item}\n"
                 # Only increase if we don't have a sublist
                 index += 1
 
+        if Document.indent_level > 0:
+            return out
         return out + "\n"
 
 
